pub type SessionEventReceiver = Receiver<SessionEvent>;Expand description
Type alias for the receiver end of the session event broadcast channel.
Aliased Type
pub struct SessionEventReceiver { /* private fields */ }pub type SessionEventReceiver = Receiver<SessionEvent>;Type alias for the receiver end of the session event broadcast channel.
pub struct SessionEventReceiver { /* private fields */ }